==> pdal-1.0.0b2-1.tar.bz2: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_util.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/lib/boost_program_options-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_iostreams-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_filesystem-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_system-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_thread-vc110-mt-1_56.lib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_util.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/pdal_util.lib" "${_IMPORT_PREFIX}/bin/pdal_util.dll" )

# Import target "pdalcpp" for configuration "Release"
set_property(TARGET pdalcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdalcpp PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdalcpp.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/lib/laszip.lib;C:/OSGeo4W64/lib/libxml2.lib;C:/dev/gdal-1.11.2/gdal.lib;C:/OSGeo4W64/lib/geos_c.lib;C:/OSGeo4W64/lib/zlib.lib;pdal_util;C:/OSGeo4W64/lib/geotiff.lib;C:/OSGeo4W64/lib/boost_program_options-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_iostreams-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_filesystem-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_system-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_thread-vc110-mt-1_56.lib;ws2_32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdalcpp.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdalcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdalcpp "${_IMPORT_PREFIX}/lib/pdalcpp.lib" "${_IMPORT_PREFIX}/bin/pdalcpp.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> pdal-1.0.1-1.tar.bz2: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_util.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/lib/boost_program_options-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_iostreams-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_filesystem-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_system-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_thread-vc110-mt-1_56.lib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_util.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/pdal_util.lib" "${_IMPORT_PREFIX}/bin/pdal_util.dll" )

# Import target "pdalcpp" for configuration "Release"
set_property(TARGET pdalcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdalcpp PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdalcpp.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/lib/laszip.lib;c:/OSGeo4W64/lib/libxml2.lib;C:/OSGeo4W64/lib/gdal_i.lib;C:/OSGeo4W64/lib/geos_c.lib;C:/OSGeo4W64/lib/zlib.lib;pdal_util;C:/OSGeo4W64/lib/geotiff_i.lib;C:/OSGeo4W64/lib/boost_program_options-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_iostreams-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_filesystem-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_system-vc110-mt-1_56.lib;C:/OSGeo4W64/lib/boost_thread-vc110-mt-1_56.lib;ws2_32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdalcpp.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdalcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdalcpp "${_IMPORT_PREFIX}/lib/pdalcpp.lib" "${_IMPORT_PREFIX}/bin/pdalcpp.dll" )

# Import target "pdal_plang" for configuration "Release"
set_property(TARGET pdal_plang APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_plang PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_plang.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "pdalcpp;C:/OSGeo4W64/apps/Python27/libs/python27.lib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_plang.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_plang )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_plang "${_IMPORT_PREFIX}/lib/pdal_plang.lib" "${_IMPORT_PREFIX}/bin/pdal_plang.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
